@@ -60,7 +60,7 @@ static const char* const TAGOPT[]={"NAME", "EXPR", "ESCAPE", "DEFAULT" };
 #include "prostate.inc"
 #include "tags.inc"
 
-static const char const tag_can_be_closed[]={
+static const char tag_can_be_closed[]={
   1 /*Bad or unsupported tag*/,
   0 /*VAR*/,
   0 /*INCLUDE*/,
@@ -72,7 +72,7 @@ static const char const tag_can_be_closed[]={
   0 /**/,
 };
 
-static const char const tag_has_opt[][6]={
+static const char tag_has_opt[][6]={
   /* "name", "expr", "escape", "default", todo, todo */
 
   { 0, 0, 0, 0, 0, 0 }, /*Bad or unsupported tag*/
@@ -88,7 +88,7 @@ static const char const tag_has_opt[][6]={
 
 typedef void (*tag_handler_func)(struct tmplpro_state *state, const PSTRING* const TagOptVal);
 
-static const tag_handler_func const output_closetag_handler[]={
+static const tag_handler_func output_closetag_handler[]={
   tag_handler_unknown,	/*Bad or unsupported tag*/
   tag_handler_unknown,	/*VAR*/
   tag_handler_unknown,	/*INCLUDE*/
@@ -99,7 +99,7 @@ static const tag_handler_func const output_closetag_handler[]={
   tag_handler_unknown,	/*ELSIF*/
   tag_handler_unknown,	/**/
 };
-static const tag_handler_func const output_opentag_handler[]={
+static const tag_handler_func output_opentag_handler[]={
   tag_handler_unknown,	/*Bad or unsupported tag*/
   tag_handler_var,	/*VAR*/
   tag_handler_include,	/*INCLUDE*/
@@ -239,7 +239,7 @@ try_tmpl_var_options (struct tmplpro_state *state, int tag_type, PSTRING* TagOpt
 	  try_tag_parameter(state, tagopt[i], TAGOPT[i])) {
 	TagOptVal[i] = read_tag_parameter_value(state);
 	found_in_loop=1;
-	if (debuglevel) log_state(state,TMPL_LOG_DEBUG,"in tag %s: found option %s\n", TAGNAME[tag_type], TAGOPT[i]);
+	if (debuglevel) log_state(state,TMPL_LOG_DEBUG,"in tag %s: found option %s=%.*s\n", TAGNAME[tag_type], TAGOPT[i],(int)(TagOptVal[i].endnext-TagOptVal[i].begin),TagOptVal[i].begin);
       }
     }
     if (!found_in_loop) opt_found = 0;
@@ -429,6 +429,7 @@ tmplpro_exec_tmpl_filename (struct tmplpro_param *param, const char* filename)
   int mmapstatus;
   PSTRING memarea;
   int retval = 0;
+  const char* saved_masterpath;
   /* 
    * param->masterpath is path to upper level template 
    * (or NULL in toplevel) which called <include filename>.
@@ -439,7 +440,8 @@ tmplpro_exec_tmpl_filename (struct tmplpro_param *param, const char* filename)
   if (NULL==filepath) return ERR_PRO_FILE_NOT_FOUND;
   /* filepath should be alive for every nested template */
   filepath = strdup(filepath);
-
+  if (NULL==filepath) return ERR_PRO_NOT_ENOUGH_MEMORY;
+  saved_masterpath=param->masterpath; /* saving current file name */
   param->masterpath=filepath;
   if (param->filters) memarea=(param->LoadFileFuncPtr)(param->ext_filter_state,filepath);
   else memarea=mmap_load_file(filepath);
@@ -458,8 +460,10 @@ tmplpro_exec_tmpl_filename (struct tmplpro_param *param, const char* filename)
   /* destroying */
   if (param->filters) mmapstatus=(param->UnloadFileFuncPtr)(param->ext_filter_state,memarea);
   else mmapstatus=mmap_unload_file(memarea);
+  if (mmapstatus && debuglevel) log_state(&state,TMPL_LOG_DEBUG, "exec_tmpl: unloading %s caused munmap error\n",filename);
  cleanup_filepath:
   if (filepath!=NULL) free((void*) filepath);
+  param->masterpath=saved_masterpath;
   return retval;
 }
 
@@ -468,12 +472,16 @@ int
 tmplpro_exec_tmpl_scalarref (struct tmplpro_param *param, PSTRING memarea)
 {
   struct tmplpro_state state;
+  const char* saved_masterpath=param->masterpath; /* saving current file name */
   param->masterpath=NULL; /* no upper file */
   state.top = memarea.begin;
   state.next_to_end=memarea.endnext;
-  if (memarea.begin == memarea.endnext) return 0;
-  init_state(&state,param);
-  process_state(&state);
+  if (memarea.begin != memarea.endnext) {
+    init_state(&state,param);
+    process_state(&state);
+  }
+  /* exit cleanup code */
+  param->masterpath=saved_masterpath;
   return 0;
 }
 
@@ -694,7 +702,7 @@ tmplpro_set_log_file(struct tmplpro_param* param, const char* logfilename)
     tmpl_log_set_callback(tmpl_log_default_callback);
     return 0;
   }
-  file_p = fopen(logfilename, "w");
+  file_p = fopen(logfilename, "a");
   if (!file_p) {
     tmpl_log(TMPL_LOG_ERROR,"tmplpro_set_log_file: can't create log file [%s]\n",logfilename);
     return ERR_PRO_FILE_NOT_FOUND;
